textblock - GooeyPy Docs

Documentation
Overview
gui

- app
- widget
- styleset
- effects

widgets

- label
- button
- input
- slider
- container
- box
- selectbox
- textblock
- image

- TextBlock
- TextBlock.font

# TextBlock

TextBlock(value) -> TextBlock widget

Basic widget for wrapping and displaying some text. Supports line breaks (ether \n or <br>)

## TextBlock.font

Label.font -> pygame.Font

The font that this label is using.